import os

# http://www.sphinx-doc.org/en/master/theming.html#distribute-your-theme-as-a-python-package
def setup(app):
    app.add_html_theme(
        'ustackdocs',
        os.path.abspath(os.path.dirname(__file__)),
    )
    return {
        'parallel_read_safe': True,
    }



# -*- coding: utf-8 -*-
import os
import sys

sys.path.insert(0, os.path.abspath('../..'))

# -- General configuration ----------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
extensions = [
    'sphinx.ext.autodoc',
    'openstackdocstheme',
    #'sphinx.ext.intersphinx',
]

# autodoc generation is a bit aggressive and a nuisance when doing heavy
# text edit cycles.
# execute "export SPHINX_DEBUG=1" in your terminal to disable

# The suffix of source filenames.
source_suffix = '.rst'

# The master toctree document.
master_doc = 'index'

# General information about the project.
project = u'ustackdocstheme'
copyright = u'2019, William Huang'

# ustackdocstheme options
repository_name = 'docs/ustackdocstheme'
html_last_updated_fmt = '%Y-%m-%d %H:%M'

# If true, '()' will be appended to :func: etc. cross-reference text.
add_function_parentheses = True

# If true, the current module name will be prepended to all description
# unit titles (such as .. function::).
add_module_names = True

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# -- Options for HTML output --------------------------------------------------

# The theme to use for HTML and HTML Help pages.  Major themes that come with
# Sphinx are currently 'default' and 'sphinxdoc'.
# html_theme_path = ["."]
# html_theme = '_theme'
# html_static_path = ['static']
html_theme = 'ustackdocs'
html_theme_options = {
    'analytics_tracking_code': False
}

# -- End options for HTML output ----------------------------------------------
